@@ -122,7 +122,7 @@ class PartitionIsFlagAvailableTestCase(RequiresPartition):
                   'PARTITION_APPLE_TV_RECOVERY',
                   'PARTITION_BIOS_GRUB', 'PARTITION_DIAG',
                   'PARTITION_MSFT_DATA', 'PARTITION_IRST',
-                  'PARTITION_ESP']:
+                  'PARTITION_ESP', 'PARTITION_NONFS']:
             if not hasattr(_ped, f):
                 continue
             attr = getattr(_ped, f)
